Documentation
¶
Index ¶
- Variables
- func AccAddress() string
- func AppGenesis(t *testing.T) *genutiltypes.AppGenesis
- func AppState(t *testing.T) map[string]json.RawMessage
- func BallotList_pell(n int, observerSet []string) []types.Ballot
- func Ballot_pell(t *testing.T, index string) *types.Ballot
- func Bech32AccAddress() sdk.AccAddress
- func BlameRecord_pell(t *testing.T, index string) types.Blame
- func BlameRecordsList_pell(t *testing.T, n int) []types.Blame
- func BlockHeader(blockHash []byte) proofs.BlockHeader
- func Bytes() []byte
- func Chain(chainID int64) *chains.Chain
- func ChainNoncesList_pell(t *testing.T, n int) []types.ChainNonces
- func ChainNonces_pell(t *testing.T, index string) types.ChainNonces
- func ChainParamsList_pell() (cpl types.ChainParamsList)
- func ChainParamsSupported_pell(chainID int64) *types.ChainParams
- func ChainParams_pell(chainID int64) *types.ChainParams
- func ChainState(chainID int64) lightclienttypes.ChainState
- func Coins() sdk.Coins
- func CreateTempDir(t *testing.T) string
- func CrosschainFlags_pell() *types.CrosschainFlags
- func CustomXmsgsInBlockRange(t *testing.T, lowBlock uint64, highBlock uint64, senderChainID int64, ...) (cctxs []*types.Xmsg)
- func EthAddress() ethcommon.Address
- func EthTx(t *testing.T, chainID int64, to ethcommon.Address, nonce uint64) (*ethtypes.Transaction, []byte)
- func EthTxSigned(t *testing.T, chainID int64, to ethcommon.Address, nonce uint64) (*ethtypes.Transaction, []byte, ethcommon.Address)
- func EventIndex() uint64
- func GasPrice_pell(t *testing.T, index string) *types.GasPrice
- func GetValidPellSent_pell(t *testing.T) (receipt ethtypes.Receipt)
- func GetXmsgIndicesFromString_pell(index string) string
- func Hash() ethcommon.Hash
- func InTxHashToXmsg_pell(t *testing.T, inTxHash string) types.InTxHashToXmsg
- func InTxTracker_pell(t *testing.T, index string) types.InTxTracker
- func InboundPellTx_PellSend_pell(r *rand.Rand) *types.InboundPellEvent
- func InboundPellTx_StakerDelegated_pell(r *rand.Rand) *types.InboundPellEvent
- func InboundPellTx_StakerDeposited_pell(r *rand.Rand) *types.InboundPellEvent
- func InboundTxParamsValidChainID_pell(r *rand.Rand) *types.InboundTxParams
- func InboundTxParams_pell(r *rand.Rand) *types.InboundTxParams
- func InboundVote_pell(from, to int64) types.MsgVoteOnObservedInboundTx
- func Int64InRange(low, high int64) int64
- func IntInRange(low, high int64) sdkmath.Int
- func Keygen_pell(t *testing.T) *types.Keygen
- func LastBlockHeight_pell(t *testing.T, index string) *types.LastBlockHeight
- func LastObserverCount_pell(lastChangeHeight int64) *types.LastRelayerCount
- func LegacyObserverMapperList_pell(t *testing.T, n int, index string) []*types.RelayerMapper
- func LegacyObserverMapper_pell(t *testing.T, index string, observerList []string) *types.RelayerMapper
- func NodeAccount_pell() *types.NodeAccount
- func NonceToXmsgList_pell(t *testing.T, index string, count int) []types.NonceToXmsg
- func NonceToXmsg_pell(t *testing.T, seed string) types.NonceToXmsg
- func ObserverSet_pell(n int) types.RelayerSet
- func OutTxTracker_pell(t *testing.T, index string) types.OutTxTracker
- func OutboundTxParamsValidChainID_pell(r *rand.Rand) *types.OutboundTxParams
- func OutboundTxParams_pell(r *rand.Rand) *types.OutboundTxParams
- func PellIndex(t *testing.T) string
- func PendingNoncesList_pell(t *testing.T, index string, count int) []types.PendingNonces
- func Policies() authoritytypes.Policies
- func PrivKeyAddressPair() (*ed25519.PrivKey, sdk.AccAddress)
- func Proof(t *testing.T) (*proofs.Proof, proofs.BlockHeader, string, int64, int64, ethcommon.Hash)
- func PubKey(r *rand.Rand) cryptotypes.PubKey
- func PubKeySet() *crypto.PubKeySet
- func PubKeyString() string
- func Rand() *rand.Rand
- func RateLimiterFlags() types.RateLimiterFlags
- func RateLimiterFlags_pell() types.RateLimiterFlags
- func Status_pell(t *testing.T, index string) *types.Status
- func String() string
- func StringRandom(r *rand.Rand, length int) string
- func SystemContract_pell() *types.SystemContract
- func TssFundsMigrator_pell(chainID int64) types.TssFundMigratorInfo
- func TssList_pell(n int) (tssList []types.TSS)
- func Tss_pell() types.TSS
- func Uint64InRange(low, high uint64) uint64
- func UintInRange(low, high uint64) sdkmath.Uint
- func ValAddress(r *rand.Rand) sdk.ValAddress
- func Validator(t testing.TB, r *rand.Rand) stakingtypes.Validator
- func VerificationFlags() lightclienttypes.VerificationFlags
- func VotesSuccessOnly_pell(voteCount int) []types.VoteType
- func WithdrawableEmissions(t *testing.T) types.WithdrawableEmissions
- func Xmsg_pell(t *testing.T, index string) *types.Xmsg
Constants ¶
This section is empty.
Variables ¶
var ErrSample = errors.New("sample error")
Functions ¶
func AppGenesis ¶
func AppGenesis(t *testing.T) *genutiltypes.AppGenesis
func Bech32AccAddress ¶
func Bech32AccAddress() sdk.AccAddress
Bech32AccAddress returns a sample account address
func BlockHeader ¶
func BlockHeader(blockHash []byte) proofs.BlockHeader
func ChainNoncesList_pell ¶
func ChainNoncesList_pell(t *testing.T, n int) []types.ChainNonces
func ChainNonces_pell ¶
func ChainNonces_pell(t *testing.T, index string) types.ChainNonces
func ChainParamsList_pell ¶
func ChainParamsList_pell() (cpl types.ChainParamsList)
func ChainParamsSupported_pell ¶
func ChainParamsSupported_pell(chainID int64) *types.ChainParams
func ChainParams_pell ¶
func ChainParams_pell(chainID int64) *types.ChainParams
func ChainState ¶
func ChainState(chainID int64) lightclienttypes.ChainState
func CreateTempDir ¶
create a temporary directory for testing
func CrosschainFlags_pell ¶
func CrosschainFlags_pell() *types.CrosschainFlags
func CustomXmsgsInBlockRange ¶
func CustomXmsgsInBlockRange( t *testing.T, lowBlock uint64, highBlock uint64, senderChainID int64, receiverChainID int64, status types.XmsgStatus, ) (cctxs []*types.Xmsg)
CustomXmsgsInBlockRange create 1 cctx per block in block range [lowBlock, highBlock] (inclusive)
func EthTx ¶
func EthTx(t *testing.T, chainID int64, to ethcommon.Address, nonce uint64) (*ethtypes.Transaction, []byte)
EthTx returns a sample ethereum transaction with the associated tx data bytes
func EthTxSigned ¶
func EthTxSigned( t *testing.T, chainID int64, to ethcommon.Address, nonce uint64, ) (*ethtypes.Transaction, []byte, ethcommon.Address)
EthTxSigned returns a sample signed ethereum transaction with the address of the sender
func EventIndex ¶
func EventIndex() uint64
func InTxHashToXmsg_pell ¶
func InTxHashToXmsg_pell(t *testing.T, inTxHash string) types.InTxHashToXmsg
func InTxTracker_pell ¶
func InTxTracker_pell(t *testing.T, index string) types.InTxTracker
func InboundPellTx_PellSend_pell ¶
func InboundPellTx_PellSend_pell(r *rand.Rand) *types.InboundPellEvent
func InboundPellTx_StakerDelegated_pell ¶
func InboundPellTx_StakerDelegated_pell(r *rand.Rand) *types.InboundPellEvent
func InboundPellTx_StakerDeposited_pell ¶
func InboundPellTx_StakerDeposited_pell(r *rand.Rand) *types.InboundPellEvent
func InboundTxParamsValidChainID_pell ¶
func InboundTxParamsValidChainID_pell(r *rand.Rand) *types.InboundTxParams
func InboundTxParams_pell ¶
func InboundTxParams_pell(r *rand.Rand) *types.InboundTxParams
func InboundVote_pell ¶
func InboundVote_pell(from, to int64) types.MsgVoteOnObservedInboundTx
func Int64InRange ¶
Int64InRange returns a sample int64 in the given ranges
func IntInRange ¶
func LastBlockHeight_pell ¶
func LastBlockHeight_pell(t *testing.T, index string) *types.LastBlockHeight
func LastObserverCount_pell ¶
func LastObserverCount_pell(lastChangeHeight int64) *types.LastRelayerCount
func NodeAccount_pell ¶
func NodeAccount_pell() *types.NodeAccount
func NonceToXmsgList_pell ¶
func NonceToXmsg_pell ¶
func NonceToXmsg_pell(t *testing.T, seed string) types.NonceToXmsg
func ObserverSet_pell ¶
func ObserverSet_pell(n int) types.RelayerSet
func OutTxTracker_pell ¶
func OutTxTracker_pell(t *testing.T, index string) types.OutTxTracker
func OutboundTxParamsValidChainID_pell ¶
func OutboundTxParamsValidChainID_pell(r *rand.Rand) *types.OutboundTxParams
func OutboundTxParams_pell ¶
func OutboundTxParams_pell(r *rand.Rand) *types.OutboundTxParams
func PendingNoncesList_pell ¶
func Policies ¶
func Policies() authoritytypes.Policies
func PrivKeyAddressPair ¶
func PrivKeyAddressPair() (*ed25519.PrivKey, sdk.AccAddress)
PrivKeyAddressPair returns a private key, address pair
func Proof ¶
Proof generates a proof and block header returns the proof, block header, block hash, tx index, chain id, and tx hash
func RateLimiterFlags ¶
func RateLimiterFlags() types.RateLimiterFlags
func RateLimiterFlags_pell ¶
func RateLimiterFlags_pell() types.RateLimiterFlags
func StringRandom ¶
StringRandom returns a sample string with random alphanumeric characters
func SystemContract_pell ¶
func SystemContract_pell() *types.SystemContract
func TssFundsMigrator_pell ¶
func TssFundsMigrator_pell(chainID int64) types.TssFundMigratorInfo
func TssList_pell ¶
func Uint64InRange ¶
Uint64InRange returns a sample uint64 in the given ranges
func UintInRange ¶
func ValAddress ¶
func ValAddress(r *rand.Rand) sdk.ValAddress
ValAddress returns a sample validator operator address
func VerificationFlags ¶
func VerificationFlags() lightclienttypes.VerificationFlags
func VotesSuccessOnly_pell ¶
func WithdrawableEmissions ¶
func WithdrawableEmissions(t *testing.T) types.WithdrawableEmissions
Types ¶
This section is empty.