Documentation
¶
Index ¶
- type XSecurityAuthorityKeeper
- type XSecurityLightclientKeeper
- type XSecurityPevmKeeper
- func (_m *XSecurityPevmKeeper) CallRegistryRouterFactory(ctx context.Context, dvsChainApprover common.Address, ...) (*types.MsgEthereumTxResponse, bool, error)
- func (_m *XSecurityPevmKeeper) CallRegistryRouterToCreateGroup(ctx cosmos_sdktypes.Context, registryRouterAddress common.Address, ...) (*types.MsgEthereumTxResponse, bool, error)
- func (_m *XSecurityPevmKeeper) CallRegistryRouterToRegisterOperator(ctx cosmos_sdktypes.Context, registryRouterAddress common.Address, ...) (*types.MsgEthereumTxResponse, bool, error)
- func (_m *XSecurityPevmKeeper) CallRegistryRouterToSetOperatorSetParams(ctx cosmos_sdktypes.Context, stakeRegistryRouterAddress common.Address, ...) (*types.MsgEthereumTxResponse, bool, error)
- func (_m *XSecurityPevmKeeper) CallStakelRegistryRouterToAddPools(ctx cosmos_sdktypes.Context, stakeRegistryRouterAddress common.Address, ...) (*types.MsgEthereumTxResponse, bool, error)
- func (_m *XSecurityPevmKeeper) CallStakelRegistryRouterToRemovePools(ctx cosmos_sdktypes.Context, stakeRegistryRouterAddress common.Address, ...) (*types.MsgEthereumTxResponse, bool, error)
- func (_m *XSecurityPevmKeeper) CallUpdateDestinationAddressOnGasSwapPEVM(ctx context.Context, chainId int64, destinationAddress string) error
- func (_m *XSecurityPevmKeeper) CallUpdateDestinationAddressOnPellGateway(ctx context.Context, chainId int64, destinationAddress string) error
- func (_m *XSecurityPevmKeeper) CallUpdateSourceAddressOnPellGateway(ctx context.Context, chainId int64, sourceAddress string) error
- type XSecurityRelayerKeeper
- type XSecurityRestakingKeeper
- type XSecuritySlashingKeeper
- type XSecurityStakingHooks
- func (_m *XSecurityStakingHooks) AfterDelegationModified(ctx context.Context, delAddr types.AccAddress, valAddr types.ValAddress) error
- func (_m *XSecurityStakingHooks) AfterValidatorBeginUnbonding(ctx context.Context, consAddr types.ConsAddress, valAddr types.ValAddress) error
- func (_m *XSecurityStakingHooks) AfterValidatorRemoved(ctx context.Context, consAddr types.ConsAddress, valAddr types.ValAddress) error
- func (_m *XSecurityStakingHooks) BeforeValidatorSlashed(ctx context.Context, valAddr types.ValAddress, fraction math.LegacyDec) error
- type XSecurityStakingKeeper
- func (_m *XSecurityStakingKeeper) BlockValidatorUpdates(ctx context.Context) ([]types.ValidatorUpdate, error)
- func (_m *XSecurityStakingKeeper) GetBondedValidatorsByPower(ctx context.Context) ([]stakingtypes.Validator, error)
- func (_m *XSecurityStakingKeeper) GetDelegation(ctx context.Context, delAddr cosmos_sdktypes.AccAddress, ...) (stakingtypes.Delegation, error)
- func (_m *XSecurityStakingKeeper) GetParams(ctx context.Context) (stakingtypes.Params, error)
- func (_m *XSecurityStakingKeeper) GetValidator(ctx context.Context, addr cosmos_sdktypes.ValAddress) (stakingtypes.Validator, error)
- func (_m *XSecurityStakingKeeper) LastValidatorsIterator(ctx context.Context) (db.Iterator, error)
- func (_m *XSecurityStakingKeeper) PowerReduction(ctx context.Context) math.Int
- func (_m *XSecurityStakingKeeper) SetValidator(ctx context.Context, validator stakingtypes.Validator) error
- func (_m *XSecurityStakingKeeper) ValidatorsPowerStoreIterator(ctx context.Context) (db.Iterator, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type XSecurityAuthorityKeeper ¶
XSecurityAuthorityKeeper is an autogenerated mock type for the XSecurityAuthorityKeeper type
func NewXSecurityAuthorityKeeper ¶
func NewXSecurityAuthorityKeeper(t interface {
mock.TestingT
Cleanup(func())
}) *XSecurityAuthorityKeeper
NewXSecurityAuthorityKeeper creates a new instance of XSecurityAuthorityKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*XSecurityAuthorityKeeper) IsAuthorized ¶
func (_m *XSecurityAuthorityKeeper) IsAuthorized(ctx types.Context, address string, policyType authoritytypes.PolicyType) bool
IsAuthorized provides a mock function with given fields: ctx, address, policyType
func (*XSecurityAuthorityKeeper) SetPolicies ¶
func (_m *XSecurityAuthorityKeeper) SetPolicies(ctx types.Context, policies authoritytypes.Policies)
SetPolicies provides a mock function with given fields: ctx, policies
type XSecurityLightclientKeeper ¶
XSecurityLightclientKeeper is an autogenerated mock type for the XSecurityLightclientKeeper type
func NewXSecurityLightclientKeeper ¶
func NewXSecurityLightclientKeeper(t interface {
mock.TestingT
Cleanup(func())
}) *XSecurityLightclientKeeper
NewXSecurityLightclientKeeper creates a new instance of XSecurityLightclientKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*XSecurityLightclientKeeper) AddBlockHeader ¶
func (_m *XSecurityLightclientKeeper) AddBlockHeader(ctx types.Context, chainID int64, height int64, blockHash []byte, header proofs.HeaderData, parentHash []byte)
AddBlockHeader provides a mock function with given fields: ctx, chainID, height, blockHash, header, parentHash
func (*XSecurityLightclientKeeper) CheckNewBlockHeader ¶
func (_m *XSecurityLightclientKeeper) CheckNewBlockHeader(ctx types.Context, chainID int64, blockHash []byte, height int64, header proofs.HeaderData) ([]byte, error)
CheckNewBlockHeader provides a mock function with given fields: ctx, chainID, blockHash, height, header
type XSecurityPevmKeeper ¶
XSecurityPevmKeeper is an autogenerated mock type for the XSecurityPevmKeeper type
func NewXSecurityPevmKeeper ¶
func NewXSecurityPevmKeeper(t interface {
mock.TestingT
Cleanup(func())
}) *XSecurityPevmKeeper
NewXSecurityPevmKeeper creates a new instance of XSecurityPevmKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*XSecurityPevmKeeper) CallRegistryRouterFactory ¶
func (_m *XSecurityPevmKeeper) CallRegistryRouterFactory(ctx context.Context, dvsChainApprover common.Address, churnApprover common.Address, ejector common.Address, pauser common.Address, unpauser common.Address, initialPausedStatus uint) (*types.MsgEthereumTxResponse, bool, error)
CallRegistryRouterFactory provides a mock function with given fields: ctx, dvsChainApprover, churnApprover, ejector, pauser, unpauser, initialPausedStatus
func (*XSecurityPevmKeeper) CallRegistryRouterToCreateGroup ¶
func (_m *XSecurityPevmKeeper) CallRegistryRouterToCreateGroup(ctx cosmos_sdktypes.Context, registryRouterAddress common.Address, operatorSetParams restakingtypes.OperatorSetParam, minimumStake int64, poolParams []restakingtypes.PoolParams, groupEjectionParams restakingtypes.GroupEjectionParam) (*types.MsgEthereumTxResponse, bool, error)
CallRegistryRouterToCreateGroup provides a mock function with given fields: ctx, registryRouterAddress, operatorSetParams, minimumStake, poolParams, groupEjectionParams
func (*XSecurityPevmKeeper) CallRegistryRouterToRegisterOperator ¶
func (_m *XSecurityPevmKeeper) CallRegistryRouterToRegisterOperator(ctx cosmos_sdktypes.Context, registryRouterAddress common.Address, param xsecuritytypes.RegisterOperatorParam, operatorAddress common.Address, groupNumbers uint64) (*types.MsgEthereumTxResponse, bool, error)
CallRegistryRouterToRegisterOperator provides a mock function with given fields: ctx, registryRouterAddress, param, operatorAddress, groupNumbers
func (*XSecurityPevmKeeper) CallRegistryRouterToSetOperatorSetParams ¶
func (_m *XSecurityPevmKeeper) CallRegistryRouterToSetOperatorSetParams(ctx cosmos_sdktypes.Context, stakeRegistryRouterAddress common.Address, groupNumbers uint64, operatorSetParams *restakingtypes.OperatorSetParam) (*types.MsgEthereumTxResponse, bool, error)
CallRegistryRouterToSetOperatorSetParams provides a mock function with given fields: ctx, stakeRegistryRouterAddress, groupNumbers, operatorSetParams
func (*XSecurityPevmKeeper) CallStakelRegistryRouterToAddPools ¶
func (_m *XSecurityPevmKeeper) CallStakelRegistryRouterToAddPools(ctx cosmos_sdktypes.Context, stakeRegistryRouterAddress common.Address, groupNumbers uint64, poolParams []*restakingtypes.PoolParams) (*types.MsgEthereumTxResponse, bool, error)
CallStakelRegistryRouterToAddPools provides a mock function with given fields: ctx, stakeRegistryRouterAddress, groupNumbers, poolParams
func (*XSecurityPevmKeeper) CallStakelRegistryRouterToRemovePools ¶
func (_m *XSecurityPevmKeeper) CallStakelRegistryRouterToRemovePools(ctx cosmos_sdktypes.Context, stakeRegistryRouterAddress common.Address, groupNumbers uint64, indicesToRemove []uint) (*types.MsgEthereumTxResponse, bool, error)
CallStakelRegistryRouterToRemovePools provides a mock function with given fields: ctx, stakeRegistryRouterAddress, groupNumbers, indicesToRemove
func (*XSecurityPevmKeeper) CallUpdateDestinationAddressOnGasSwapPEVM ¶
func (_m *XSecurityPevmKeeper) CallUpdateDestinationAddressOnGasSwapPEVM(ctx context.Context, chainId int64, destinationAddress string) error
CallUpdateDestinationAddressOnGasSwapPEVM provides a mock function with given fields: ctx, chainId, destinationAddress
func (*XSecurityPevmKeeper) CallUpdateDestinationAddressOnPellGateway ¶
func (_m *XSecurityPevmKeeper) CallUpdateDestinationAddressOnPellGateway(ctx context.Context, chainId int64, destinationAddress string) error
CallUpdateDestinationAddressOnPellGateway provides a mock function with given fields: ctx, chainId, destinationAddress
func (*XSecurityPevmKeeper) CallUpdateSourceAddressOnPellGateway ¶
func (_m *XSecurityPevmKeeper) CallUpdateSourceAddressOnPellGateway(ctx context.Context, chainId int64, sourceAddress string) error
CallUpdateSourceAddressOnPellGateway provides a mock function with given fields: ctx, chainId, sourceAddress
type XSecurityRelayerKeeper ¶
XSecurityRelayerKeeper is an autogenerated mock type for the XSecurityRelayerKeeper type
func NewXSecurityRelayerKeeper ¶
func NewXSecurityRelayerKeeper(t interface {
mock.TestingT
Cleanup(func())
}) *XSecurityRelayerKeeper
NewXSecurityRelayerKeeper creates a new instance of XSecurityRelayerKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
type XSecurityRestakingKeeper ¶
XSecurityRestakingKeeper is an autogenerated mock type for the XSecurityRestakingKeeper type
func NewXSecurityRestakingKeeper ¶
func NewXSecurityRestakingKeeper(t interface {
mock.TestingT
Cleanup(func())
}) *XSecurityRestakingKeeper
NewXSecurityRestakingKeeper creates a new instance of XSecurityRestakingKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*XSecurityRestakingKeeper) GetAllShares ¶
func (_m *XSecurityRestakingKeeper) GetAllShares(ctx types.Context) []*restakingtypes.OperatorShares
GetAllShares provides a mock function with given fields: ctx
type XSecuritySlashingKeeper ¶
XSecuritySlashingKeeper is an autogenerated mock type for the XSecuritySlashingKeeper type
func NewXSecuritySlashingKeeper ¶
func NewXSecuritySlashingKeeper(t interface {
mock.TestingT
Cleanup(func())
}) *XSecuritySlashingKeeper
NewXSecuritySlashingKeeper creates a new instance of XSecuritySlashingKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*XSecuritySlashingKeeper) IsTombstoned ¶
func (_m *XSecuritySlashingKeeper) IsTombstoned(ctx context.Context, addr types.ConsAddress) bool
IsTombstoned provides a mock function with given fields: ctx, addr
func (*XSecuritySlashingKeeper) SetValidatorSigningInfo ¶
func (_m *XSecuritySlashingKeeper) SetValidatorSigningInfo(ctx context.Context, address types.ConsAddress, info slashingtypes.ValidatorSigningInfo) error
SetValidatorSigningInfo provides a mock function with given fields: ctx, address, info
type XSecurityStakingHooks ¶
XSecurityStakingHooks is an autogenerated mock type for the XSecurityStakingHooks type
func NewXSecurityStakingHooks ¶
func NewXSecurityStakingHooks(t interface {
mock.TestingT
Cleanup(func())
}) *XSecurityStakingHooks
NewXSecurityStakingHooks creates a new instance of XSecurityStakingHooks. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*XSecurityStakingHooks) AfterDelegationModified ¶
func (_m *XSecurityStakingHooks) AfterDelegationModified(ctx context.Context, delAddr types.AccAddress, valAddr types.ValAddress) error
AfterDelegationModified provides a mock function with given fields: ctx, delAddr, valAddr
func (*XSecurityStakingHooks) AfterValidatorBeginUnbonding ¶
func (_m *XSecurityStakingHooks) AfterValidatorBeginUnbonding(ctx context.Context, consAddr types.ConsAddress, valAddr types.ValAddress) error
AfterValidatorBeginUnbonding provides a mock function with given fields: ctx, consAddr, valAddr
func (*XSecurityStakingHooks) AfterValidatorRemoved ¶
func (_m *XSecurityStakingHooks) AfterValidatorRemoved(ctx context.Context, consAddr types.ConsAddress, valAddr types.ValAddress) error
AfterValidatorRemoved provides a mock function with given fields: ctx, consAddr, valAddr
func (*XSecurityStakingHooks) BeforeValidatorSlashed ¶
func (_m *XSecurityStakingHooks) BeforeValidatorSlashed(ctx context.Context, valAddr types.ValAddress, fraction math.LegacyDec) error
BeforeValidatorSlashed provides a mock function with given fields: ctx, valAddr, fraction
type XSecurityStakingKeeper ¶
XSecurityStakingKeeper is an autogenerated mock type for the XSecurityStakingKeeper type
func NewXSecurityStakingKeeper ¶
func NewXSecurityStakingKeeper(t interface {
mock.TestingT
Cleanup(func())
}) *XSecurityStakingKeeper
NewXSecurityStakingKeeper creates a new instance of XSecurityStakingKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*XSecurityStakingKeeper) BlockValidatorUpdates ¶
func (_m *XSecurityStakingKeeper) BlockValidatorUpdates(ctx context.Context) ([]types.ValidatorUpdate, error)
BlockValidatorUpdates provides a mock function with given fields: ctx
func (*XSecurityStakingKeeper) GetBondedValidatorsByPower ¶
func (_m *XSecurityStakingKeeper) GetBondedValidatorsByPower(ctx context.Context) ([]stakingtypes.Validator, error)
GetBondedValidatorsByPower provides a mock function with given fields: ctx
func (*XSecurityStakingKeeper) GetDelegation ¶
func (_m *XSecurityStakingKeeper) GetDelegation(ctx context.Context, delAddr cosmos_sdktypes.AccAddress, valAddr cosmos_sdktypes.ValAddress) (stakingtypes.Delegation, error)
GetDelegation provides a mock function with given fields: ctx, delAddr, valAddr
func (*XSecurityStakingKeeper) GetParams ¶
func (_m *XSecurityStakingKeeper) GetParams(ctx context.Context) (stakingtypes.Params, error)
GetParams provides a mock function with given fields: ctx
func (*XSecurityStakingKeeper) GetValidator ¶
func (_m *XSecurityStakingKeeper) GetValidator(ctx context.Context, addr cosmos_sdktypes.ValAddress) (stakingtypes.Validator, error)
GetValidator provides a mock function with given fields: ctx, addr
func (*XSecurityStakingKeeper) LastValidatorsIterator ¶
LastValidatorsIterator provides a mock function with given fields: ctx
func (*XSecurityStakingKeeper) PowerReduction ¶
func (_m *XSecurityStakingKeeper) PowerReduction(ctx context.Context) math.Int
PowerReduction provides a mock function with given fields: ctx
func (*XSecurityStakingKeeper) SetValidator ¶
func (_m *XSecurityStakingKeeper) SetValidator(ctx context.Context, validator stakingtypes.Validator) error
SetValidator provides a mock function with given fields: ctx, validator
func (*XSecurityStakingKeeper) ValidatorsPowerStoreIterator ¶
func (_m *XSecurityStakingKeeper) ValidatorsPowerStoreIterator(ctx context.Context) (db.Iterator, error)
ValidatorsPowerStoreIterator provides a mock function with given fields: ctx